@@ -13,7 +13,7 @@ use deno_core::op;
 use deno_runtime::deno_broadcast_channel::InMemoryBroadcastChannel;
 use deno_runtime::deno_core;
 use deno_runtime::deno_web::BlobStore;
-use deno_runtime::permissions::Permissions;
+use deno_runtime::permissions::{Permissions, PermissionsContainer};
 use deno_runtime::worker::MainWorker;
 use deno_runtime::worker::WorkerOptions;
 
@@ -23,8 +23,10 @@ use std::thread::JoinHandle;
 use crate::anyhow::anyhow;
 use futures::channel::{mpsc, mpsc::Sender, oneshot};
 use futures_util::{SinkExt, StreamExt};
+use resvg::FitTo;
+use usvg::{TreeParsing, TreeTextToPath};
 
-use crate::text::{op_text_width, USVG_OPTIONS};
+use crate::text::{op_text_width, FONT_DB, USVG_OPTIONS};
 
 lazy_static! {
     pub static ref TOKIO_RUNTIME: tokio::runtime::Runtime =
@@ -100,7 +102,7 @@ struct InnerVlConverter {
 impl InnerVlConverter {
     async fn init_vega(&mut self) -> Result<(), AnyError> {
         if !self.vega_initialized {
-            let import_str = format!(
+            let import_code = format!(
                 r#"
 var vega;
 import('{vega_url}').then((imported) => {{
@@ -116,19 +118,22 @@ import('{vega_themes_url}').then((imported) => {{
                 vega_themes_url = vega_themes_url(),
             );
 
-            self.worker.execute_script("<anon>", &import_str)?;
+            self.worker.execute_script("<anon>", &import_code)?;
             self.worker.run_event_loop(false).await?;
 
             // Override text width measurement in vega-scenegraph
             for path in self.module_loader.import_map.keys() {
                 if path.ends_with("vega-scenegraph.js") {
-                    let script = format!(
+                    let script_code = format!(
                         r#"
 import('{url}').then((sg) => {{
     sg.textMetrics.width = (item, text) => {{
         let style = item.fontStyle;
         let variant = item.fontVariant;
-        let weight = item.fontWeight;
+
+        // weight may be string like "bold" or number like 600.
+        // Convert number form to string
+        let weight = String(item.fontWeight);
         let size = sg.fontSize(item);
         let family = sg.fontFamily(item);
 
@@ -136,13 +141,13 @@ import('{url}').then((sg) => {{
             style, variant, weight, size, family, text
         }}, null, 2);
 
-        return Deno.core.ops.op_text_width(text_info)
+        return Deno[Deno.internal].core.ops.op_text_width(text_info)
     }};
 }})
 "#,
                         url = url_for_path(path)
                     );
-                    self.worker.execute_script("<anon>", &script)?;
+                    self.worker.execute_script("<anon>", &script_code)?;
                     self.worker.run_event_loop(false).await?;
                 }
             }
@@ -169,7 +174,7 @@ function vegaToSvg(vgSpec) {
     async fn init_vl_version(&mut self, vl_version: &VlVersion) -> Result<(), AnyError> {
         if !self.initialized_vl_versions.contains(vl_version) {
             // Create and evaluate import string
-            let import_str = format!(
+            let import_code = format!(
                 r#"
 var {ver_name};
 import('{vl_url}').then((imported) => {{
@@ -180,12 +185,12 @@ import('{vl_url}').then((imported) => {{
                 vl_url = vl_version.to_url()
             );
 
-            self.worker.execute_script("<anon>", &import_str)?;
+            self.worker.execute_script("<anon>", &import_code)?;
 
             self.worker.run_event_loop(false).await?;
 
             // Create and initialize function string
-            let function_str = format!(
+            let function_code = format!(
                 r#"
 function compileVegaLite_{ver_name}(vlSpec, config, theme) {{
     let options = {{}};
@@ -221,7 +226,7 @@ function vegaLiteToSvg_{ver_name}(vlSpec, config, theme) {{
                 ver_name = format!("{:?}", vl_version),
             );
 
-            self.worker.execute_script("<anon>", &function_str)?;
+            self.worker.execute_script("<anon>", &function_code)?;
 
             self.worker.run_event_loop(false).await?;
 
@@ -234,7 +239,7 @@ function vegaLiteToSvg_{ver_name}(vlSpec, config, theme) {{
     pub async fn try_new() -> Result<Self, AnyError> {
         let module_loader = Rc::new(VlConvertModuleLoader::new());
 
-        let ext = Extension::builder()
+        let ext = Extension::builder("vl_convert_extensions")
             .ops(vec![
                 // Op to measure text width with resvg
                 op_text_width::decl(),
@@ -252,6 +257,7 @@ function vegaLiteToSvg_{ver_name}(vlSpec, config, theme) {{
         let options = WorkerOptions {
             bootstrap: Default::default(),
             extensions: vec![ext],
+            extensions_with_js: vec![],
             startup_snapshot: None,
             unsafely_ignore_certificate_errors: None,
             root_cert_store: None,
@@ -278,7 +284,7 @@ function vegaLiteToSvg_{ver_name}(vlSpec, config, theme) {{
 
         let js_path = Path::new(env!("CARGO_MANIFEST_DIR")).join("vl-convert-rs.js");
         let main_module = deno_core::resolve_path(&js_path.to_string_lossy())?;
-        let permissions = Permissions::allow_all();
+        let permissions = PermissionsContainer::new(Permissions::allow_all());
 
         let mut worker =
             MainWorker::bootstrap_from_options(main_module.clone(), permissions, options);
@@ -360,8 +366,8 @@ function vegaLiteToSvg_{ver_name}(vlSpec, config, theme) {{
         let code = format!(
             r#"
 compileVegaLite_{ver_name:?}(
-    JSON.parse(Deno.core.ops.op_get_json_arg({spec_arg_id})),
-    JSON.parse(Deno.core.ops.op_get_json_arg({config_arg_id})),
+    JSON.parse(Deno[Deno.internal].core.ops.op_get_json_arg({spec_arg_id})),
+    JSON.parse(Deno[Deno.internal].core.ops.op_get_json_arg({config_arg_id})),
     {theme_arg}
 )
 "#,
@@ -395,8 +401,8 @@ compileVegaLite_{ver_name:?}(
             r#"
 var svg;
 vegaLiteToSvg_{ver_name:?}(
-    JSON.parse(Deno.core.ops.op_get_json_arg({spec_arg_id})),
-    JSON.parse(Deno.core.ops.op_get_json_arg({config_arg_id})),
+    JSON.parse(Deno[Deno.internal].core.ops.op_get_json_arg({spec_arg_id})),
+    JSON.parse(Deno[Deno.internal].core.ops.op_get_json_arg({config_arg_id})),
     {theme_arg}
 ).then((result) => {{
     svg = result;
@@ -422,7 +428,7 @@ vegaLiteToSvg_{ver_name:?}(
             r#"
 var svg;
 vegaToSvg(
-    JSON.parse(Deno.core.ops.op_get_json_arg({arg_id}))
+    JSON.parse(Deno[Deno.internal].core.ops.op_get_json_arg({arg_id}))
 ).then((result) => {{
     svg = result;
 }})
@@ -685,13 +691,20 @@ impl VlConverter {
         let opts = USVG_OPTIONS
             .lock()
             .map_err(|err| anyhow!("Failed to acquire usvg options lock: {}", err.to_string()))?;
-        let rtree = match usvg::Tree::from_str(svg, &opts.to_ref()) {
+
+        let font_database = FONT_DB
+            .lock()
+            .map_err(|err| anyhow!("Failed to acquire fontdb lock: {}", err.to_string()))?;
+
+        let mut rtree = match usvg::Tree::from_str(svg, &opts) {
             Ok(rtree) => rtree,
             Err(err) => {
                 bail!("Failed to parse SVG string: {}", err.to_string())
             }
         };
 
+        rtree.convert_text(&font_database);
+
         let pixmap_size = rtree.size.to_screen_size();
         let mut pixmap = tiny_skia::Pixmap::new(
             (pixmap_size.width() as f32 * scale) as u32,
@@ -700,7 +713,7 @@ impl VlConverter {
         .unwrap();
         resvg::render(
             &rtree,
-            usvg::FitTo::Zoom(scale),
+            FitTo::Zoom(scale),
             tiny_skia::Transform::default(),
             pixmap.as_mut(),
         )
