@@ -2,8 +2,12 @@
 
 pub mod converter;
 pub mod module_loader;
+pub mod text;
+
+#[macro_use]
+extern crate lazy_static;
 
 pub use converter::VlConverter;
-pub use deno_core::anyhow;
+pub use deno_runtime::deno_core::anyhow;
 pub use module_loader::import_map::VlVersion;
 pub use serde_json;
