@@ -97,12 +97,13 @@ mod test_vegalite_to_vega {
     fn test(
         #[values(
             VlVersion::v4_17,
-            VlVersion::v5_0,
-            VlVersion::v5_1,
-            VlVersion::v5_2,
             VlVersion::v5_3,
             VlVersion::v5_4,
-            VlVersion::v5_5
+            VlVersion::v5_5,
+            VlVersion::v5_6,
+            VlVersion::v5_7,
+            VlVersion::v5_8,
+            VlVersion::v5_9,
         )]
         vl_version: VlVersion,
 
@@ -153,13 +154,14 @@ mod test_svg {
             "circle_binned",
             "stacked_bar_h",
             "bar_chart_trellis_compact",
-            "line_with_log_scale"
+            "line_with_log_scale",
+            "numeric_font_weight"
         )]
         name: &str,
     ) {
         initialize();
 
-        let vl_version = VlVersion::v5_5;
+        let vl_version = VlVersion::v5_8;
 
         // Load example Vega-Lite spec
         let vl_spec = load_vl_spec(name);
@@ -209,7 +211,7 @@ mod test_png {
     ) {
         initialize();
 
-        let vl_version = VlVersion::v5_5;
+        let vl_version = VlVersion::v5_8;
 
         // Load example Vega-Lite spec
         let vl_spec = load_vl_spec(name);
@@ -264,7 +266,7 @@ mod test_png_theme_config {
     ) {
         initialize();
 
-        let vl_version = VlVersion::v5_5;
+        let vl_version = VlVersion::v5_8;
 
         // Load example Vega-Lite spec
         let vl_spec = load_vl_spec(name);
@@ -290,7 +292,7 @@ mod test_png_theme_config {
 
         // Patch spec to put theme in `vl_spec.usermeta.embedOptions.theme` and don't pass theme
         // argument
-        let mut usermeta_spec = vl_spec.clone();
+        let mut usermeta_spec = vl_spec;
         let usermeta_spec_obj = usermeta_spec.as_object_mut().unwrap();
         usermeta_spec_obj.insert("usermeta".to_string(), json!({
             "embedOptions": {"theme": theme.to_string()}
@@ -319,7 +321,7 @@ mod test_png_theme_config {
 
 #[tokio::test]
 async fn test_font_with_quotes() {
-    let vl_version = VlVersion::v5_5;
+    let vl_version = VlVersion::v5_8;
 
     // Load example Vega-Lite spec
     let name = "font_with_quotes";
